==> qhull-2019.1-4-x86_64.pkg.tar.zst: usr/lib/cmake/Qhull/QhullTargets-noconfig.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file.
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Qhull::qhullcpp" for configuration ""
set_property(TARGET Qhull::qhullcpp APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(Qhull::qhullcpp PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_NOCONFIG "CXX"
  IMPORTED_LOCATION_NOCONFIG "/usr/lib/libqhullcpp.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qhull::qhullcpp )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qhull::qhullcpp "/usr/lib/libqhullcpp.a" )

# Import target "Qhull::qhull_r" for configuration ""
set_property(TARGET Qhull::qhull_r APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(Qhull::qhull_r PROPERTIES
  IMPORTED_LOCATION_NOCONFIG "/usr/lib/libqhull_r.so.7.3.2"
  IMPORTED_SONAME_NOCONFIG "libqhull_r.so.7"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qhull::qhull_r )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qhull::qhull_r "/usr/lib/libqhull_r.so.7.3.2" )

# Import target "Qhull::qhull" for configuration ""
set_property(TARGET Qhull::qhull APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(Qhull::qhull PROPERTIES
  IMPORTED_LOCATION_NOCONFIG "/usr/bin/qhull"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qhull::qhull )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qhull::qhull "/usr/bin/qhull" )

# Import target "Qhull::rbox" for configuration ""
set_property(TARGET Qhull::rbox APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(Qhull::rbox PROPERTIES
  IMPORTED_LOCATION_NOCONFIG "/usr/bin/rbox"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qhull::rbox )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qhull::rbox "/usr/bin/rbox" )

# Import target "Qhull::qconvex" for configuration ""
set_property(TARGET Qhull::qconvex APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(Qhull::qconvex PROPERTIES
  IMPORTED_LOCATION_NOCONFIG "/usr/bin/qconvex"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qhull::qconvex )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qhull::qconvex "/usr/bin/qconvex" )

# Import target "Qhull::qdelaunay" for configuration ""
set_property(TARGET Qhull::qdelaunay APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(Qhull::qdelaunay PROPERTIES
  IMPORTED_LOCATION_NOCONFIG "/usr/bin/qdelaunay"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qhull::qdelaunay )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qhull::qdelaunay "/usr/bin/qdelaunay" )

# Import target "Qhull::qvoronoi" for configuration ""
set_property(TARGET Qhull::qvoronoi APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(Qhull::qvoronoi PROPERTIES
  IMPORTED_LOCATION_NOCONFIG "/usr/bin/qvoronoi"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qhull::qvoronoi )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qhull::qvoronoi "/usr/bin/qvoronoi" )

# Import target "Qhull::qhalf" for configuration ""
set_property(TARGET Qhull::qhalf APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(Qhull::qhalf PROPERTIES
  IMPORTED_LOCATION_NOCONFIG "/usr/bin/qhalf"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qhull::qhalf )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qhull::qhalf "/usr/bin/qhalf" )

# Import target "Qhull::libqhull" for configuration ""
set_property(TARGET Qhull::libqhull APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(Qhull::libqhull PROPERTIES
  IMPORTED_LOCATION_NOCONFIG "/usr/lib/libqhull.so.7.3.2"
  IMPORTED_SONAME_NOCONFIG "libqhull.so.7"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qhull::libqhull )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qhull::libqhull "/usr/lib/libqhull.so.7.3.2" )

# Import target "Qhull::qhull_p" for configuration ""
set_property(TARGET Qhull::qhull_p APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(Qhull::qhull_p PROPERTIES
  IMPORTED_LOCATION_NOCONFIG "/usr/lib/libqhull_p.so.7.3.2"
  IMPORTED_SONAME_NOCONFIG "libqhull_p.so.7"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qhull::qhull_p )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qhull::qhull_p "/usr/lib/libqhull_p.so.7.3.2" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> qhull-2020.1-1-x86_64.pkg.tar.zst: usr/lib/cmake/Qhull/QhullTargets-noconfig.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file.
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Qhull::qhullcpp" for configuration ""
set_property(TARGET Qhull::qhullcpp APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(Qhull::qhullcpp PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_NOCONFIG "CXX"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libqhullcpp.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qhull::qhullcpp )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qhull::qhullcpp "${_IMPORT_PREFIX}/lib/libqhullcpp.a" )

# Import target "Qhull::qhull_r" for configuration ""
set_property(TARGET Qhull::qhull_r APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(Qhull::qhull_r PROPERTIES
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libqhull_r.so.8.0.0"
  IMPORTED_SONAME_NOCONFIG "libqhull_r.so.8.0"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qhull::qhull_r )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qhull::qhull_r "${_IMPORT_PREFIX}/lib/libqhull_r.so.8.0.0" )

# Import target "Qhull::qhull" for configuration ""
set_property(TARGET Qhull::qhull APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(Qhull::qhull PROPERTIES
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/bin/qhull"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qhull::qhull )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qhull::qhull "${_IMPORT_PREFIX}/bin/qhull" )

# Import target "Qhull::rbox" for configuration ""
set_property(TARGET Qhull::rbox APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(Qhull::rbox PROPERTIES
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/bin/rbox"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qhull::rbox )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qhull::rbox "${_IMPORT_PREFIX}/bin/rbox" )

# Import target "Qhull::qconvex" for configuration ""
set_property(TARGET Qhull::qconvex APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(Qhull::qconvex PROPERTIES
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/bin/qconvex"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qhull::qconvex )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qhull::qconvex "${_IMPORT_PREFIX}/bin/qconvex" )

# Import target "Qhull::qdelaunay" for configuration ""
set_property(TARGET Qhull::qdelaunay APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(Qhull::qdelaunay PROPERTIES
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/bin/qdelaunay"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qhull::qdelaunay )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qhull::qdelaunay "${_IMPORT_PREFIX}/bin/qdelaunay" )

# Import target "Qhull::qvoronoi" for configuration ""
set_property(TARGET Qhull::qvoronoi APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(Qhull::qvoronoi PROPERTIES
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/bin/qvoronoi"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qhull::qvoronoi )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qhull::qvoronoi "${_IMPORT_PREFIX}/bin/qvoronoi" )

# Import target "Qhull::qhalf" for configuration ""
set_property(TARGET Qhull::qhalf APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(Qhull::qhalf PROPERTIES
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/bin/qhalf"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qhull::qhalf )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qhull::qhalf "${_IMPORT_PREFIX}/bin/qhalf" )

# Import target "Qhull::libqhull" for configuration ""
set_property(TARGET Qhull::libqhull APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(Qhull::libqhull PROPERTIES
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libqhull.so.8.0.0"
  IMPORTED_SONAME_NOCONFIG "libqhull.so.8.0"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qhull::libqhull )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qhull::libqhull "${_IMPORT_PREFIX}/lib/libqhull.so.8.0.0" )

# Import target "Qhull::qhull_p" for configuration ""
set_property(TARGET Qhull::qhull_p APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(Qhull::qhull_p PROPERTIES
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libqhull_p.so.8.0.0"
  IMPORTED_SONAME_NOCONFIG "libqhull_p.so.8.0"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qhull::qhull_p )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qhull::qhull_p "${_IMPORT_PREFIX}/lib/libqhull_p.so.8.0.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
